Predict Rosetta Parameter Values and Standard Deviations from a Rosetta instance

# S3 method for class 'Rosetta'
predict(object, soildata, ...)

Arguments

object

Rosetta object containing class instance (e.g. from Rosetta())

soildata

A list containing vectors; with number of parameters matching the model type of object

...

not used

Value

A list containing mean and stdev matrices (one row per sample).

For rosetta-soil >= 0.3, the columns are: theta_r, theta_s, alpha, npar, ksat. Note that these parameters are in the scale produced by the underlying model (often log10 for alpha, npar, and ksat).

Examples

# predict(Rosetta(), list(c(30, 30, 40, 1.5), c(55, 25, 20, 1.1)))