Run rosesoil() from rosetta-soil >= 0.3.0
rosesoil(soildata, rosetta_version = 3, estimate_type = "arith", vars = NULL)A list of numeric vectors or a data.frame (3-6 columns: sand, silt, clay, optionally bulk density, th33, and th1500)
integer, 1-3. Default: 3
character. One of "arith" (default), "log", or "geo". Only used if rosetta-soil >= 0.3.1. "log" returns parameters on a logarithmic (log10) scale for alpha, npar, ksat, and k0. "geo" returns the geometric mean of bootstrap estimates (exponent of the mean of log-transformed values). This is often preferred for parameters that vary by orders of magnitude, such as alpha and ksat.
optional column name mapping (same as run_rosetta)
a data.frame with all RosettaResult fields