Run rosetta() method from Python module
# Default S3 method
run_rosetta(
soildata,
vars = NULL,
rosetta_version = 3,
estimate_type = "log",
...
)
# S3 method for class 'data.frame'
run_rosetta(
soildata,
vars = NULL,
rosetta_version = 3,
estimate_type = "log",
...
)
# S3 method for class 'matrix'
run_rosetta(
soildata,
vars = NULL,
rosetta_version = 3,
estimate_type = "log",
...
)
# S3 method for class 'RasterStack'
run_rosetta(
soildata,
vars = NULL,
rosetta_version = 3,
estimate_type = "log",
cores = 1,
core_thresh = 20000L,
file = paste0(tempfile(), ".tif"),
nrows = nrow(soildata)/(terra::ncell(soildata)/core_thresh),
overwrite = TRUE
)
# S3 method for class 'RasterBrick'
run_rosetta(
soildata,
vars = NULL,
rosetta_version = 3,
estimate_type = "log",
cores = 1,
core_thresh = 20000L,
file = paste0(tempfile(), ".tif"),
nrows = nrow(soildata)/(terra::ncell(soildata)/core_thresh),
overwrite = TRUE
)
# S3 method for class 'SpatRaster'
run_rosetta(
soildata,
vars = NULL,
rosetta_version = 3,
estimate_type = "log",
cores = 1,
core_thresh = 20000L,
file = paste0(tempfile(), ".tif"),
nrows = nrow(soildata)/(terra::ncell(soildata)/core_thresh),
overwrite = TRUE
)A list of numeric vectors each containing 3 to 6 values: "sand", "silt", "clay", "bulkdensity", "th33", "th1500", a data.frame or matrix with 3 to 6 columns OR a Raster*/SpatRaster object with 3 to 6 layers. Sand, silt, and clay must sum to a total of 100%.
character. Optional: names and order of custom column names if soildata is a data.frame, RasterStack, RasterBrick or SpatRaster. Default NULL assumes input column order follows sand, silt, clay, bulkdensity, th33, th1500 and does not check names.
Default: 3
character. One of "log" (default), "arith", or "geo". Only used if rosetta-soil >= 0.3.1. Default "log" preserves logarithmic (log10) scale for alpha, npar, and Ksat. "geo" returns the geometric mean of bootstrap estimates (exponent of the mean of log-transformed values). This is often preferred for parameters that vary by orders of magnitude, such as alpha and Ksat.
additional arguments not used
number of cores; used only for processing SpatRaster or Raster* input
Magic number for determining processing chunk size. Default 20000L. Used to calculate default nrows
path to write incremental raster processing output for large inputs that do not fit in memory; passed to terra::writeStart() and used only for processing SpatRaster or Raster* input; defaults to a temporary file created by tempfile() if needed
number of rows to use per block chunk; passed to terra::readValues() and terra::writeValues(); used only for processing SpatRaster or Raster* inputs. Defaults to the total number of rows divided by the number of cells divided by core_thresh.
logical; overwrite file? passed to terra::writeStart(); defaults to TRUE if needed
A data.frame containing mean and stdev for the following columns (parameters for van Genuchten-Mualem equation)
"theta_r", residual water content
"theta_s", saturated water content
"alpha", 'alpha' shape parameter (1/cm). Logarithmic (log10) scale if estimate_type="log" (default); Geometric mean if estimate_type="geo".
"npar", 'n' shape parameter. Logarithmic (log10) scale if estimate_type="log" (default); Geometric mean if estimate_type="geo".
"Ksat", saturated hydraulic conductivity (cm/day). Logarithmic (log10) scale if estimate_type="log" (default); Geometric mean if estimate_type="geo".
"K0", unsaturated hydraulic conductivity (cm/day). Only if rosetta-soil >= 0.3.1. Logarithmic (log10) scale if estimate_type="log" (default); Geometric mean if estimate_type="geo".
"lpar", unsaturated hydraulic conductivity exponent. Only if rosetta-soil >= 0.3.1.
If the sum of sand, silt, and clay is not 100%, the parameter value estimates will be NaN.